/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.coyotesong.compress.archivers.dump.test;

import com.coyotesong.compress.archivers.dump.DumpArchiveEntry;
import com.coyotesong.compress.archivers.dump.DumpArchiveInputStream;

//import org.jruby.ext.posix.POSIX;
//import org.jruby.ext.posix.POSIXFactory;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;


/**
 * Test application that extracts files from an archive.
 *
 * FIXME: JNA support for linux permissions...
 *
 * @author Bear Giles <bgiles@coyotesong.com>
 */
public class TestExtract {
    /**
     * @param args
     * @throws Exception
     */
    public static void main(String[] args) throws Exception {
        InputStream is = new FileInputStream(new File(
                    "/home/bgiles/testdata/test-dump.z.001"));

        DumpArchiveInputStream dis = new DumpArchiveInputStream(is);

        //POSIX posix = POSIXFactory.loadLinuxPOSIX(null);
        String prefix = "/home/bgiles/dumptest/";

        DumpArchiveEntry e;

        while ((e = dis.getNextEntry()) != null) {
        	//System.out.println(e.getName());
            if (e.isDirectory()) {
                File dir = new File(prefix + e.getName());
                dir.mkdirs();
            } else {
                File file = new File(prefix + e.getName());

                try {
                    OutputStream os = new FileOutputStream(file);
                    byte[] buffer = new byte[1024];
                    int n;

                    while ((n = dis.read(buffer, 0, buffer.length)) > 0) {
                        os.write(buffer, 0, n);
                    }

                    os.close();
                } catch (FileNotFoundException ee) {
                    System.out.println(ee);
                }
            }

            long[] atimevals = new long[2];
            long[] mtimevals = new long[2];
            atimevals[0] = (int) (e.getAccessTime().getTime() / 1000L);
            atimevals[1] = (int) (1000L * (e.getAccessTime().getTime() % 1000L));
            mtimevals[0] = (int) (e.getModificationTime().getTime() / 1000L);
            mtimevals[1] = (int) (1000L * (e.getModificationTime().getTime() % 1000L));

            //posix.utimes(prefix + e.getName(), atimevals, mtimevals);
            //posix.chmod(prefix + e.getName(), e.getMode());
            //posix.chown(prefix + e.getName(), e.getUserId(), e.getGroupId());
        }

        dis.close();
    }
}
